Acme::DonMartin - For programs that are easy to dictate over the telephone
This document describes version 0.01 of Acme::DonMartin, released 2005-04-08.
use Acme::DonMartin; print "Hello world\n";
Perl is a very difficult language to dictate over the phone. All those pesky punctuation characters and gruesome glyphs make it very laborious to speak out loud.
To compound the problem, most people can't even agree on what something as basic as # should be called. Some of the names for it (although by no means exhaustive) include:
#
pound, pound sign, number sign, flash, hash, sharp, grid, crosshatch, octothorpe, square, pig-pen, hex, tictactoe, scratchmark, crunch, thud, thump, splat.
(I think with the last few variants that you can see where this is going).
The first time you run a program under Acme::DonMartin, your source code is magically transformed into Don Martin cartoon sound effects. The code continues to work as before, but now it looks like this:
Acme::DonMartin
#! /usr/local/bin/perl use Acme::DonMartin; gashlikt ahweeeeee dipada fliff gahak dapada zap thwizzik gahork tik gark dakdik gleet skroook skronk chomple dig klooonn sloople tik fling splork gleet cook chook wiz bombah boomer poong glong shuka spatz
Now you can pick up the phone and dictate it to someone else and they can type it in to a computer and run it with much less chance of confusion or error.
This can also be construed as a security feature. It is expected that a hacker will be laughing too hard to be able to recover the source code.
zownt thlip spoosh
Something weird happened.
None known.
Please report any bugs or feature requests to bug-acme-donmartin@rt.cpan.org, or through the web interface at http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-DonMartin.
bug-acme-donmartin@rt.cpan.org
Copyright (C) 2005, David Landgren, all rights reserved.
Acme::Bleach, Acme::Buffy, Acme::Bushisms, Acme::Morse, Acme::Ook, Acme::Pony, Acme::Python, etc. etc. and of course http://en.wikipedia.org/wiki/Don_Martin
To install Acme::DonMartin, copy and paste the appropriate command in to your terminal.
cpanm
cpanm Acme::DonMartin
CPAN shell
perl -MCPAN -e shell install Acme::DonMartin
For more information on module installation, please visit the detailed CPAN module installation guide.